﻿Imports System
Imports System.Collections.Generic
Imports System.Collections.ObjectModel
Imports System.ComponentModel
Imports System.Linq
Imports System.Runtime.CompilerServices
Imports System.Text
Imports System.Threading.Tasks

Public Class DirectoryItemViewModel
    Implements INotifyPropertyChanged

    Public Sub New()
    End Sub

    Public Sub New(ByVal fullPath As String, ByVal type As DirectoryItemTypeEnum)
        fullPath = fullPath
        type = type
        ClearDirectoryItems()
    End Sub

    Private _fullPath As String
    Public Property FullPath As String
        Get
            Return _fullPath
        End Get
        Set(ByVal value As String)
            If _fullPath <> value Then
                _fullPath = value
                RaisePropertyChanged(NameOf(FullPath))
            End If
        End Set
    End Property

    Public ReadOnly Property Name As String
        Get
            Return If(Type = DirectoryItemTypeEnum.Drive, FullPath, FullPath.GetFileFolderName())
        End Get
    End Property

    Private _type As DirectoryItemTypeEnum
    Public Property Type As DirectoryItemTypeEnum
        Get
            Return _type
        End Get
        Set(ByVal value As DirectoryItemTypeEnum)
            If _type <> value Then
                _type = value
                RaisePropertyChanged(NameOf(Type))
            End If
        End Set
    End Property





    Private _childItems As ObservableCollection(Of DirectoryItemViewModel)
    Public Property ChildItems As ObservableCollection(Of DirectoryItemViewModel)
        Get
            Return _childItems
        End Get
        Set(ByVal value As ObservableCollection(Of DirectoryItemViewModel))

            If _childItems IsNot value Then
                _childItems = value
                RaisePropertyChanged(NameOf(ChildItems))
            End If
        End Set
    End Property

    Public ReadOnly Property CanExpand As Boolean
        Get
            Return Type <> DirectoryItemTypeEnum.File
        End Get
    End Property

    Public Property IsExpanded As Boolean
        Get
            Return ChildItems.Count > 0
        End Get
        Set(ByVal value As Boolean)

            If value = True Then
                Expand()
            Else
                ClearDirectoryItems()
            End If

            RaisePropertyChanged(NameOf(IsExpanded))

        End Set
    End Property

    Private Sub Expand()
        If Type = DirectoryItemTypeEnum.File Then Return
        Dim childItems2 = FullPath.GetFolders()

        ChildItems = New ObservableCollection(Of DirectoryItemViewModel)(childItems2.[Select](Function(child) New DirectoryItemViewModel(child.FullPath, child.Type)))
    End Sub

    Private Sub ClearDirectoryItems()
        ChildItems = New ObservableCollection(Of DirectoryItemViewModel)()
        If Type <> DirectoryItemTypeEnum.File Then ChildItems.Add(Nothing)
    End Sub




    Public Event PropertyChanged As PropertyChangedEventHandler Implements INotifyPropertyChanged.PropertyChanged
    Protected Overridable Sub RaisePropertyChanged(<CallerMemberName> Optional ByVal prop As String = "")
        RaiseEvent PropertyChanged(Me, New PropertyChangedEventArgs(prop))
    End Sub

End Class