﻿Imports System
Imports System.Collections.Generic
Imports System.IO
Imports System.Linq
Imports System.Runtime.CompilerServices

Module DirectoryStructure
    Function GetLogicalDrives() As List(Of DirectoryItem)
        Return Directory.GetLogicalDrives().[Select](Function(d) New DirectoryItem With {.FullPath = d, .Type = DirectoryItemTypeEnum.Drive}).ToList()
    End Function

    <Extension()>
    Function GetFolders(ByVal path As String) As List(Of DirectoryItem)
        Dim items = New List(Of DirectoryItem)()
        If Not Directory.Exists(path) Then Return New List(Of DirectoryItem)()
        Dim folders = Directory.GetDirectories(path)

        If folders.Length > 0 Then
            items.AddRange(folders.[Select](Function(f) New DirectoryItem With {.FullPath = f, .Type = DirectoryItemTypeEnum.Folder}))
        End If

        Return items
    End Function

    <Extension()>
    Function GetFilesFolders(ByVal path As String) As List(Of DirectoryItem)
        Dim items = New List(Of DirectoryItem)()
        If Not Directory.Exists(path) Then Return New List(Of DirectoryItem)()
        Dim folders = Directory.GetDirectories(path)
        Dim files = Directory.GetFiles(path)

        If folders.Length > 0 Then
            items.AddRange(folders.[Select](Function(f) New DirectoryItem With {.FullPath = f, .Type = DirectoryItemTypeEnum.Folder}))
        End If

        If files.Length > 0 Then
            items.AddRange(files.[Select](Function(f) New DirectoryItem With {.FullPath = f, .Type = DirectoryItemTypeEnum.File}))
        End If

        Return items
    End Function

    <Extension()>
    Function GetFileFolderName(ByVal path As String) As String
        If String.IsNullOrEmpty(path) Then Return String.Empty
        Dim replacedPath = path.Replace("/"c, "\"c)
        Dim lastIndexOfSlash = replacedPath.LastIndexOf("\"c)
        If lastIndexOfSlash <= 0 Then Return path
        Return path.Substring(lastIndexOfSlash + 1)
    End Function
End Module
